summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetepasswordwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/kopetepasswordwidget.h')
-rw-r--r--kopete/libkopete/ui/kopetepasswordwidget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/ui/kopetepasswordwidget.h b/kopete/libkopete/ui/kopetepasswordwidget.h
index e8c45a90..d4ad2c11 100644
--- a/kopete/libkopete/ui/kopetepasswordwidget.h
+++ b/kopete/libkopete/ui/kopetepasswordwidget.h
@@ -42,11 +42,11 @@ class KOPETE_EXPORT PasswordWidget : public KopetePasswordWidgetBase
public:
/**
* Creates a Kopete::PasswordWidget.
* @param tqparent The widget to nest this one inside
* @param name The name of this TQObject
* @param from The password to load the data for this widget from, or 0 if none
*/
- PasswordWidget( TQWidget *tqparent, const char *name = 0, Kopete::Password *from = 0 );
+ PasswordWidget( TQWidget *parent, const char *name = 0, Kopete::Password *from = 0 );
~PasswordWidget();
/**
@@ -42,11 +42,11 @@ class KOPETE_EXPORT PasswordWidget : public KopetePasswordWidgetBase
/**
* Creates a Kopete::PasswordWidget.
- * @param tqparent The widget to nest this one inside
+ * @param parent The widget to nest this one inside
* @param name The name of this TQObject
* @param from The password to load the data for this widget from, or 0 if none